@@ -148,11 +148,11 @@ void LasWriter::addArgs(ProgramArgs& args)
     args.add("major_version", "LAS major version", d->opts.majorVersion,
         decltype(d->opts.majorVersion)(1));
     args.add("minor_version", "LAS minor version", d->opts.minorVersion,
-        decltype(d->opts.minorVersion)(2));
+        decltype(d->opts.minorVersion)(4));
     args.add("dataformat_id", "Point format", d->opts.dataformatId,
-        decltype(d->opts.dataformatId)(3));
+        decltype(d->opts.dataformatId)(7));
     args.add("format", "Point format", d->opts.dataformatId,
-        decltype(d->opts.dataformatId)(3));
+        decltype(d->opts.dataformatId)(7));
     args.add("global_encoding", "Global encoding byte", d->opts.globalEncoding,
         decltype(d->opts.globalEncoding)(0));
     args.add("project_id", "Project ID", d->opts.projectId);
@@ -637,6 +637,12 @@ void LasWriter::addVlr(const las::Evlr& evlr)
             throwError("Can't write VLR with user ID/record ID = " +
                 evlr.userId + "/" + std::to_string(evlr.recordId) +
                 ".  The data size exceeds the maximum supported.");
+    } else if (evlr.writeAsEVLR)
+    {
+        if (d->header.versionAtLeast(1, 4))
+            m_evlrs.push_back(std::move(evlr));
+        else
+            throwError("User specified writing as EVLR but the file is not a 1.4+ file!");
     }
     else
         m_vlrs.push_back(std::move(evlr));
